Release Notes — Message For You Sir! v0.2.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Message For You Sir! v0.2.1 documentation »

# Release Notes

Below is the list of the important changes found in each release of Message For You Sir!.

## Release 0.2.1

Release date: 2012-02-08

- Updated the decorator depencency to version 3.3.2 to make installation work again.
- Fixed a couple other development environment bugs.

## Release 0.2

Release date: 2011-04-18

- Fixed several bugs in the tests.
- Added and improved many docstrings.
- All the testing infrastructure has been greatly changed. Testing is now structured into test bases and test mixins. This is in order to support organising tests by logical functionality and to support test reuse.
- Removed nose and strait as testing dependencies.
- Removed zope.component and zope.event as dependencies.
- Added a paver test command to run all tests.
- Added a function for running all tests outside of the development environment. This lets users run the tests in production and other non-development environments. Just call `m4us.tests.run()` from the python interpreter or python -m m4us.tests.__init__ from the command-line.
- Made unittest2 and mock full dependencies in order to support running tests any time.
- Coroutines and coroutine factory functions can now have additional interfaces. The `coroutine()` decorator no longer masks them.
- `backplane()` is now a function. The Backplane class has been removed. The function behaves identically.
- The name of the first parameter to the `publish_to()` function has been changed to backplane_.
- Removed import-time side effects. The `init()` function must now be called explicitly before running anything else. It can either be called at import time, or very early in a program's main function.
- Renamed the `IPostOffice` link() and unlink() methods to `register()` and `unregister()` respectively.
- Renamed the `IScheduler` add() and remove() methods to `register()` and `unregister()` respectively.
- `IContainer` has been changed slightly. The `coroutines` and `links` are now both defined as immutable sequences.
- Added a `filter_from_callable()` convenience function that can turn a one parameter function into a filter coroutine.
- Added a `producer_from_iterable()` convenience function that can turn an iterable into a producer coroutine.
- Added a `sink_from_callable()` convenience function that can turn a one parameter function into a sink coroutine.
- Added a `filter_()` convenience decorator that works like `filter_from_callable()` but as a decorator.
- Added a `producer()` convenience decorator that works like `producer_from_iterable()` but as a decorator.
- Added a `sink()` convenience decorator that works like `sink_from_callable()` but as a decorator.
- Updated example.py to use the new features and properly handle Unicode strings.
- Changed the behaviour and command-line options of the paver lint, paver tests_lint and paver check commands. They now work more reliable and have better support for being in an IDE.

## Release 0.1.1

Release date: 2010-12-21

- Fixed a bug with files missing from the source distribution.

## Release 0.1

Release date: 2010-12-21

- Initial Release.

### Navigation

- index
- modules |
- next |
- previous |
- Message For You Sir! v0.2.1 documentation »